Struct ModelReap

pub struct ModelReap;
Reap plugin family’s child model over the LazyBalance’s compile-time marker via ShareBalanceContext.

Bound to ShareBalanceFamily via LazyBalanceRoot::Reap.

Overview

Removes value from the balance without modifying issued shares.

This decreases effective while keeping issued constant, thereby decreasing bias (value per share).

Effect

  • effective -= asset
  • issued remains unchanged
  • bias = effective / issued is recomputed

This proportionally reduces the value of all existing shares implicitly, which is lazily reflected during withdrawal.

Full Drain

If effective becomes zero:

  • bias is set to zero
  • drainpoint (time-reference) is recorded for optimized withdrawals

This marks the balance as fully drained. Deposits are disallowed in this state until new value is introduced via minting. In this state withdrawals shall be simply zero valued until minted further.

Constraints

  • zero-value reap is a no-op
  • balance must not be fresh (must be initialized)
  • balance must have existing deposits (issued > 0)
  • subtraction from effective must not underflow

Semantics

Reaping represents value removal:

  • no shares are burned
  • all existing receipts lose value proportionally lazily.

Withdrawals ensures correct lazy resolution for receipts across drained states.